@@ -8,8 +8,14 @@ from gmat.uvlmm.varcom.pxem2 import pxem_mme2, pxem_vmat2
 
 
 from gmat.uvlmm.varcom.ai import ai_vmat, ai_mme
+from gmat.uvlmm.varcom.newton import newton_vmat
+from gmat.uvlmm.varcom.fisher import fisher_vmat
 
 
 from gmat.uvlmm.varcom.weight_emai import weight_emai_vmat, weight_emai_mme
+from gmat.uvlmm.varcom.weight_emai_eigen import weight_emai_eigen
 
 from gmat.uvlmm.varcom.weight_pxemai import weight_pxemai_vmat, weight_pxemai_mme
+
+from gmat.uvlmm.varcom.weight_emnewton import weight_emnewton_vmat
+from gmat.uvlmm.varcom.weight_emfisher import weight_emfisher_vmat
